pub struct CapsuleAgent { /* private fields */ }Expand description
Auto-generated bindings for an instance a component which
implements the world capsule-agent.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
CapsuleAgent::instantiate_asyncwhich only needs aStore,Component, andLinker. -
Alternatively you can create a
CapsuleAgentPreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesCapsuleAgentPre::instantiate_asyncto create aCapsuleAgent. -
If you’ve instantiated the instance yourself already then you can use
CapsuleAgent::new. -
You can also access the guts of instantiation through
CapsuleAgentIndices::new_instancefollowed byCapsuleAgentIndices::loadto crate an instance of this type.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl CapsuleAgent
impl CapsuleAgent
Sourcepub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<CapsuleAgent>where
_T: Send,
pub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<CapsuleAgent>where
_T: Send,
Convenience wrapper around CapsuleAgentPre::new and
CapsuleAgentPre::instantiate_async.
Sourcepub fn new(
store: impl AsContextMut,
instance: &Instance,
) -> Result<CapsuleAgent>
pub fn new( store: impl AsContextMut, instance: &Instance, ) -> Result<CapsuleAgent>
Convenience wrapper around CapsuleAgentIndices::new_instance and
CapsuleAgentIndices::load.
pub fn add_to_linker<T, U>( linker: &mut Linker<T>, get: impl Fn(&mut T) -> &mut U + Send + Sync + Copy + 'static, ) -> Result<()>
pub fn capsule_host_task_runner(&self) -> &Guest