pub struct State {
pub ctx: WasiCtx,
pub http_ctx: WasiHttpCtx,
pub table: ResourceTable,
pub limits: StoreLimits,
pub runtime: Option<Arc<Runtime>>,
pub policy: ExecutionPolicy,
}Fields
ctx: WasiCtxhttp_ctx: WasiHttpCtxtable: ResourceTablelimits: StoreLimitsruntime: Option<Arc<Runtime>>policy: ExecutionPolicyTrait Implementations
Sourceimpl ResourceLimiter for State
impl ResourceLimiter for State
Sourcefn memory_growing(
&mut self,
current: usize,
desired: usize,
maximum: Option<usize>,
) -> Result<bool>
fn memory_growing( &mut self, current: usize, desired: usize, maximum: Option<usize>, ) -> Result<bool>
Notifies the resource limiter that an instance’s linear memory has been
requested to grow. Read more
Sourcefn table_growing(
&mut self,
current: usize,
desired: usize,
maximum: Option<usize>,
) -> Result<bool>
fn table_growing( &mut self, current: usize, desired: usize, maximum: Option<usize>, ) -> Result<bool>
Notifies the resource limiter that an instance’s table has been
requested to grow. Read more
Sourcefn memory_grow_failed(&mut self, error: Error) -> Result<(), Error>
fn memory_grow_failed(&mut self, error: Error) -> Result<(), Error>
Notifies the resource limiter that growing a linear memory, permitted by
the
memory_growing method, has failed. Read moreSourcefn table_grow_failed(&mut self, error: Error) -> Result<(), Error>
fn table_grow_failed(&mut self, error: Error) -> Result<(), Error>
Notifies the resource limiter that growing a linear memory, permitted by
the
table_growing method, has failed. Read moreSourcefn instances(&self) -> usize
fn instances(&self) -> usize
The maximum number of instances that can be created for a
Store. Read moreSourceimpl WasiHttpView for State
impl WasiHttpView for State
Sourcefn ctx(&mut self) -> &mut WasiHttpCtx
fn ctx(&mut self) -> &mut WasiHttpCtx
Returns a mutable reference to the WASI HTTP context.
Sourcefn table(&mut self) -> &mut ResourceTable
fn table(&mut self) -> &mut ResourceTable
Returns a mutable reference to the WASI HTTP resource table.
Sourcefn send_request(
&mut self,
request: Request<HyperOutgoingBody>,
config: OutgoingRequestConfig,
) -> HttpResult<HostFutureIncomingResponse>
fn send_request( &mut self, request: Request<HyperOutgoingBody>, config: OutgoingRequestConfig, ) -> HttpResult<HostFutureIncomingResponse>
Send an outgoing request.
Sourcefn new_incoming_request<B>(
&mut self,
scheme: Scheme,
req: Request<B>,
) -> Result<Resource<HostIncomingRequest>, Error>
fn new_incoming_request<B>( &mut self, scheme: Scheme, req: Request<B>, ) -> Result<Resource<HostIncomingRequest>, Error>
Create a new incoming request resource.
Sourcefn new_response_outparam(
&mut self,
result: Sender<Result<Response<BoxBody<Bytes, ErrorCode>>, ErrorCode>>,
) -> Result<Resource<HostResponseOutparam>, Error>
fn new_response_outparam( &mut self, result: Sender<Result<Response<BoxBody<Bytes, ErrorCode>>, ErrorCode>>, ) -> Result<Resource<HostResponseOutparam>, Error>
Create a new outgoing response resource.
Sourcefn is_forbidden_header(&mut self, _name: &HeaderName) -> bool
fn is_forbidden_header(&mut self, _name: &HeaderName) -> bool
Whether a given header should be considered forbidden and not allowed.
Sourcefn outgoing_body_buffer_chunks(&mut self) -> usize
fn outgoing_body_buffer_chunks(&mut self) -> usize
Number of distinct write calls to the outgoing body’s output-stream
that the implementation will buffer.
Default: 1.
Sourcefn outgoing_body_chunk_size(&mut self) -> usize
fn outgoing_body_chunk_size(&mut self) -> usize
Maximum size allowed in a write call to the outgoing body’s output-stream.
Default: 1024 * 1024.